@@ -24,7 +24,8 @@ DEFAULT_K = 32
 
 def main():
     parser = argparse.ArgumentParser(
-        description="Annotate seqs with partitions.")
+        description="Annotate seqs with partitions.",
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
 
     parser.add_argument('--ksize', '-k', type=int, default=DEFAULT_K,
                         help="k-mer size (default: %d)" % DEFAULT_K)
