@@ -15,7 +15,7 @@ Use '-h' for parameter help.
 import os
 import khmer
 from khmer.thread_utils import ThreadedSequenceProcessor, verbose_loader
-
+from khmer import threading_args as targs
 from khmer.counting_args import build_counting_multifile_args
 
 #
@@ -26,6 +26,7 @@ DEFAULT_CUTOFF = 2
 
 def main():
     parser = build_counting_multifile_args()
+    targs.add_threading_args(parser)
     parser.add_argument('--cutoff', '-C', dest='cutoff',
                         default=DEFAULT_CUTOFF, type=int,
                         help="Trim at k-mers below this abundance.")
@@ -36,11 +37,14 @@ def main():
                         help='base variable-coverage cutoff on this median'
                         ' k-mer abundance',
                         default=DEFAULT_NORMALIZE_LIMIT)
-
+    parser.add_argument('-o', '--out', dest='single_output_filename',
+                        default='', help='only output a single'
+                        ' file with the specified filename')
     args = parser.parse_args()
 
     counting_ht = args.input_table
     infiles = args.input_filenames
+    n_threads = int(args.n_threads)
 
     print 'file with ht: %s' % counting_ht
 
@@ -72,10 +76,14 @@ def main():
     # the filtering loop
     for infile in infiles:
         print 'filtering', infile
-        outfile = os.path.basename(infile) + '.abundfilt'
-        outfp = open(outfile, 'w')
+        if args.single_output_filename != '':
+            outfile = args.single_output_filename
+            outfp = open(outfile, 'a')
+        else:
+            outfile = os.path.basename(infile) + '.abundfilt'
+            outfp = open(outfile, 'w')
 
-        tsp = ThreadedSequenceProcessor(process_fn)
+        tsp = ThreadedSequenceProcessor(process_fn, n_workers=n_threads)
         tsp.start(verbose_loader(infile), outfp)
 
         print 'output in', outfile
