@@ -26,7 +26,8 @@ DEFAULT_K = 32
 
 
 def main():
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
 
     parser.add_argument('-k', default=DEFAULT_K, type=int, help='k-mer size',
                         dest='ksize')
