@@ -18,7 +18,9 @@ import screed
 import os
 import khmer
 from itertools import izip
-from khmer.counting_args import build_construct_args, DEFAULT_MIN_HASHSIZE
+from khmer.khmer_args import build_counting_args, DEFAULT_MIN_HASHSIZE
+from khmer.khmer_args import add_loadhash_args
+from khmer.khmer_args import report_on_config
 import argparse
 
 DEFAULT_DESIRED_COVERAGE = 10
@@ -109,59 +111,46 @@ def normalize_by_median(input_filename, outfp, ht, args, report_fp=None):
     return total, discarded
 
 
-def handle_error(error, output_name, input_name, ht):
+def handle_error(error, output_name, input_name, fail_save, ht):
     print >>sys.stderr, '** ERROR:', error
     print >>sys.stderr, '** Failed on {name}: '.format(name=input_name)
-    hashname = os.path.basename(input_name) + '.ht.failed'
-    print >>sys.stderr, '** ...dumping hashtable to {ht}'.format(ht=hashname)
-    ht.save(hashname)
+    if fail_save:
+        hashname = os.path.basename(input_name) + '.ht.failed'
+        print >>sys.stderr,\
+            '** ...dumping hashtable to {ht}'.format(ht=hashname)
+        ht.save(hashname)
     try:
         os.remove(output_name)
     except:
-        print >>sys.stderr, '** ERROR: problem removing erroneous .keep file'
+        print >>sys.stderr, '** ERROR: problem removing corrupt filtered file'
 
 
 def main():
-    parser = build_construct_args()
+    parser = build_counting_args()
     parser.add_argument('-C', '--cutoff', type=int, dest='cutoff',
                         default=DEFAULT_DESIRED_COVERAGE)
     parser.add_argument('-p', '--paired', action='store_true')
     parser.add_argument('-s', '--savehash', dest='savehash', default='')
-    parser.add_argument('-l', '--loadhash', dest='loadhash',
-                        default='')
     parser.add_argument('-R', '--report-to-file', dest='report_file',
                         type=argparse.FileType('w'))
-    parser.add_argument('-f', '--force-processing', dest='force',
+    parser.add_argument('-f', '--fault-tolerant', dest='force',
                         help='continue on next file if read errors are \
                          encountered', action='store_true')
+    parser.add_argument('--save-on-failure', dest='fail_save',
+                        action='store_false', default=True,
+                        help='Save hashtable when an error occurs')
     parser.add_argument('-d', '--dump-frequency', dest='dump_frequency',
                         type=int, help='dump hashtable every d files',
                         default=-1)
+    parser.add_argument('-o', '--out', dest='single_output_filename',
+                        default='', help='only output a single'
+                        ' file with the specified filename')
     parser.add_argument('input_filenames', nargs='+')
+    add_loadhash_args(parser)
 
     args = parser.parse_args()
 
-    if not args.quiet:
-        if args.min_hashsize == DEFAULT_MIN_HASHSIZE:
-            print >>sys.stderr, \
-                "** WARNING: hashsize is default!  " \
-                "You absodefly want to increase this!\n** " \
-                "Please read the docs!"
-
-        print >>sys.stderr, '\nPARAMETERS:'
-        print >>sys.stderr, \
-            ' - kmer size =    {ksize:d} \t\t(-k)'.format(ksize=args.ksize)
-        print >>sys.stderr, \
-            ' - n hashes =     {nhash:d} \t\t(-N)'.format(nhash=args.n_hashes)
-        print >>sys.stderr, \
-            ' - min hashsize = {mh:-5.2g} \t(-x)'.format(mh=args.min_hashsize)
-        print >>sys.stderr, ' - paired = {pr} \t\t(-p)'.format(pr=args.paired)
-        print >>sys.stderr, ''
-        print >>sys.stderr, \
-            'Estimated memory usage is {prod:.2g} bytes \
-            (n_hashes x min_hashsize)'.format(prod=args.n_hashes
-                                              * args.min_hashsize)
-        print >>sys.stderr, '-' * 8
+    report_on_config(args)
 
     K = args.ksize
     HT_SIZE = args.min_hashsize
@@ -171,6 +160,7 @@ def main():
     filenames = args.input_filenames
     force = args.force
     dump_frequency = args.dump_frequency
+    fail_save = args.fail_save
 
     # list to save error files along with throwing exceptions
     if force is True:
@@ -187,8 +177,12 @@ def main():
     discarded = 0
 
     for n, input_filename in enumerate(filenames):
-        output_name = os.path.basename(input_filename) + '.keep'
-        outfp = open(output_name, 'w')
+        if args.single_output_filename != '':
+            output_name = args.single_output_filename
+            outfp = open(args.single_output_filename, 'a')
+        else:
+            output_name = os.path.basename(input_filename) + '.keep'
+            outfp = open(output_name, 'w')
 
         total_acc = 0
         discarded_acc = 0
@@ -198,10 +192,10 @@ def main():
                                                            outfp, ht, args,
                                                            report_fp)
         except IOError as e:
-            handle_error(e, output_name, input_filename, ht)
+            handle_error(e, output_name, input_filename, fail_save, ht)
             if not force:
                 print >>sys.stderr, '** Exiting!'
-                sys.exit(-1)
+                sys.exit(1)
             else:
                 print >>sys.stderr, '*** Skipping error file, moving on...'
                 corrupt_files.append(input_filename)
@@ -248,7 +242,7 @@ def main():
         print >>sys.stderr, "** this data set.  Increase hashsize/num ht."
         print >>sys.stderr, "**"
         print >>sys.stderr, "** Do not use these results!!"
-        sys.exit(-1)
+        sys.exit(1)
 
 if __name__ == '__main__':
     main()
