@@ -7,6 +7,7 @@ import sys
 import os
 import shutil
 from cStringIO import StringIO
+import subprocess
 import traceback
 
 import khmer_tst_utils as utils
@@ -105,6 +106,37 @@ def DEBUG_runscript(scriptname, args, in_directory=None, fail_ok=False):
 #
 
 
+# When testing argparse related options execfile does not work
+# TODO: figure out why replacing runscript with popenscript uses more memory
+def popenscript(scriptname, args, in_directory=None, fail_ok=False):
+    """
+    Run the given Python script, with the given args, in the given directory,
+    using 'Popen'.
+    """
+
+    out, err = None, None
+
+    try:
+        print 'running:', scriptname, 'in:', in_directory
+        print 'arguments', args
+        complete_args = [scriptname]
+        complete_args.extend(args)
+        process = subprocess.Popen(complete_args,
+                                   stdout=subprocess.PIPE,
+                                   stderr=subprocess.PIPE,
+                                   cwd=in_directory)
+        out, err = process.communicate()
+        status = process.returncode
+    except:
+        traceback.print_exc(file=sys.stderr)
+        status = -1
+
+    if status != 0 and not fail_ok:
+        raise Exception(status, out, err)
+
+    return status, out, err
+
+
 def test_load_into_counting():
     script = scriptpath('load-into-counting.py')
     args = ['-x', '1e7', '-N', '2', '-k', '20']
@@ -353,6 +385,14 @@ def test_normalize_by_median():
     assert seqs[0].startswith('GGTTGACGGGGCTCAGGGGG'), seqs
 
 
+def test_normalize_by_median_version():
+
+    script = scriptpath('normalize-by-median.py')
+    args = ['--version']
+    status, out, err = popenscript(script, args)
+    assert err.startswith('khmer ')
+
+
 def test_normalize_by_median_2():
     CUTOFF = '2'
 
@@ -436,6 +476,27 @@ def test_normalize_by_median_force():
     assert '** IOErrors' in err
 
 
+def test_normalize_by_median_no_bigcount():
+    infile = utils.get_temp_filename('test.fa')
+    hashfile = utils.get_temp_filename('test-out.kh')
+    outfile = infile + '.keep'
+
+    shutil.copyfile(utils.get_test_data('test-abund-read-2.fa'), infile)
+    counting_ht = _make_counting(infile, K=8)
+
+    script = scriptpath('normalize-by-median.py')
+    args = ['-C', '1000', '-k 8', '--savehash', hashfile, infile]
+
+    (status, out, err) = runscript(script, args)
+    assert status == 0, (out, err)
+    print (out, err)
+
+    assert os.path.exists(hashfile), hashfile
+    kh = khmer.load_counting_hash(hashfile)
+
+    assert kh.get('GGTTGACG') == 255
+
+
 def test_normalize_by_median_dumpfrequency():
     CUTOFF = '1'
 
@@ -681,10 +742,11 @@ def test_partition_graph_1():
     assert os.path.exists(final_pmap_file)
 
     ht = khmer.load_hashbits(graphbase + '.ht')
+    ht.load_tagset(graphbase + '.tagset')
     ht.load_partitionmap(final_pmap_file)
 
     x = ht.count_partitions()
-    assert x == (1, 0)          # should be exactly one partition.
+    assert x == (1, 0), x          # should be exactly one partition.
 
 
 def test_partition_graph_nojoin_k21():
@@ -704,10 +766,11 @@ def test_partition_graph_nojoin_k21():
     assert os.path.exists(final_pmap_file)
 
     ht = khmer.load_hashbits(graphbase + '.ht')
+    ht.load_tagset(graphbase + '.tagset')
     ht.load_partitionmap(final_pmap_file)
 
     x = ht.count_partitions()
-    assert x == (99, 0)          # should be 99 partitions at K=21
+    assert x == (99, 0), x          # should be 99 partitions at K=21
 
 
 def test_partition_graph_nojoin_stoptags():
@@ -735,10 +798,11 @@ def test_partition_graph_nojoin_stoptags():
     assert os.path.exists(final_pmap_file)
 
     ht = khmer.load_hashbits(graphbase + '.ht')
+    ht.load_tagset(graphbase + '.tagset')
     ht.load_partitionmap(final_pmap_file)
 
     x = ht.count_partitions()
-    assert x == (2, 0)          # should be 2 partitions
+    assert x == (2, 0), x          # should be 2 partitions
 
 
 def test_partition_graph_big_traverse():
@@ -749,10 +813,11 @@ def test_partition_graph_big_traverse():
     assert os.path.exists(final_pmap_file)
 
     ht = khmer.load_hashbits(graphbase + '.ht')
+    ht.load_tagset(graphbase + '.tagset')
     ht.load_partitionmap(final_pmap_file)
 
     x = ht.count_partitions()
-    assert x == (1, 0)          # should be exactly one partition.
+    assert x == (1, 0), x          # should be exactly one partition.
 
 
 def test_partition_graph_no_big_traverse():
@@ -764,10 +829,11 @@ def test_partition_graph_no_big_traverse():
     assert os.path.exists(final_pmap_file)
 
     ht = khmer.load_hashbits(graphbase + '.ht')
+    ht.load_tagset(graphbase + '.tagset')
     ht.load_partitionmap(final_pmap_file)
 
     x = ht.count_partitions()
-    assert x == (4, 0), x       # should be four partitions, broken at knot.
+    assert x[0] == 4, x       # should be four partitions, broken at knot.
 
 
 def test_annotate_partitions():
@@ -843,6 +909,39 @@ def test_extract_partitions():
     assert len(parts) == 1, len(parts)
 
 
+def test_extract_partitions_fq():
+    seqfile = utils.get_test_data('random-20-a.fq')
+    graphbase = _make_graph(
+        seqfile, do_partition=True, annotate_partitions=True)
+    in_dir = os.path.dirname(graphbase)
+
+    # get the final part file
+    partfile = os.path.join(in_dir, 'random-20-a.fq.part')
+
+    # ok, now run extract-partitions.
+    script = scriptpath('extract-partitions.py')
+    args = ['extracted', partfile]
+
+    runscript(script, args, in_dir)
+
+    distfile = os.path.join(in_dir, 'extracted.dist')
+    groupfile = os.path.join(in_dir, 'extracted.group0000.fq')
+    assert os.path.exists(distfile)
+    assert os.path.exists(groupfile)
+
+    dist = open(distfile).readline()
+    assert dist.strip() == '99 1 1 99'
+
+    parts = [r.name.split('\t')[1] for r in screed.open(partfile)]
+    assert len(parts) == 99, len(parts)
+    parts = set(parts)
+    assert len(parts) == 1, len(parts)
+
+    quals = set([r.accuracy for r in screed.open(partfile)])
+    quals = list(quals)
+    assert quals[0], quals
+
+
 def test_abundance_dist():
     infile = utils.get_temp_filename('test.fa')
     outfile = utils.get_temp_filename('test.dist')
@@ -1169,3 +1268,43 @@ def test_sample_reads_randomly():
                         '895:1:1:1327:15301', '895:1:1:1265:2265',
                         '895:1:1:1327:13028', '895:1:1:1368:4434',
                         '895:1:1:1335:19932', '895:1:1:1340:19387'])
+
+
+def test_sweep_reads_by_partition_buffered():
+    readfile = utils.get_temp_filename('reads.fa')
+    contigfile = utils.get_temp_filename('contigs.fp')
+    in_dir = os.path.dirname(contigfile)
+
+    shutil.copyfile(utils.get_test_data('test-sweep-reads.fa'), readfile)
+    shutil.copyfile(utils.get_test_data('test-sweep-contigs.fp'), contigfile)
+
+    script = scriptpath('sweep-reads-by-partition-buffered.py')
+    args = ['-k', '25', '-o', 'test',
+            contigfile, readfile, 'junkfile.fa']
+    status, out, err = runscript(script, args, in_dir)
+
+    # check if the bad file was skipped without issue
+    assert 'ERROR' in err
+    assert 'skipping' in err
+
+    out1 = os.path.join(in_dir, 'test_0.fa')
+    out2 = os.path.join(in_dir, 'test_1.fa')
+    mout = os.path.join(in_dir, 'test_multi.fa')
+    oout = os.path.join(in_dir, 'test_orphaned.fa')
+
+    print os.listdir(in_dir)
+
+    seqs1 = set([r.name for r in screed.open(out1)])
+    seqs2 = set([r.name for r in screed.open(out2)])
+    seqsm = set([r.name for r in screed.open(mout)])
+    seqso = set([r.name for r in screed.open(oout)])
+
+    print seqs1
+    print seqs2
+    print seqsm
+    print seqso
+    assert seqs1 == set(['read1_p0\t0', 'read2_p0\t0'])
+    assert seqs2 == set(['read3_p1\t1'])
+    assert (seqsm == set(['read4_multi\t0\t1']) or
+            seqsm == set(['read4_multi\t1\t0']))
+    assert seqso == set(['read5_orphan'])
